@@ -1,10 +1,14 @@
 from .data.data import DisplayType, AudioPadding, ListOrdering
 from .data.config import Config
 from .data.librosa_stft_args import LibrosaSTFTArgs
-from .processors.abstract_data_processor import AbstractDataProcessor, AbstractFitDataProcessor
+from .processors.abstract_data_processor import AbstractDataProcessor, AbstractFitDataProcessor, AbstractDestructiveDataProcessor
 from .processors.scaler_audio_processor import ScalerAudioProcessor
+from .processors.simple_scaling_processor import SimpleScalingProcessor
 from .spectrogram.multi_spectrogram import MultiSpectrogram
 from .spectrogram.spectrogram_factory import SpectrogramFactory
+from .stft_complexe_processor.abstract_stft_processor import AbstractStftComplexProcessor
+from .stft_complexe_processor.mag_phase_stft_processor import MagnitudePhaseStftProcessor
+from .stft_complexe_processor.real_imag_stft_processor import RealImageStftProcessor
 
 try:
     from ._version import version as __version__
